# SPDX-FileCopyrightText: 2024-present Johan du Plessis https://github.com/johanslab
#
# SPDX-License-Identifier: MIT
"""
Version information.
"""

__version__ = "0.1.3"
__author__ = "Johan du Plessis"
